==> igniteui-angular-charts-16.1.2-beta.0.tgz: package/esm2015/lib/igx-bar-fragment-component.js <==
import { Component, forwardRef, ChangeDetectionStrategy } from '@angular/core';
import { IgxNumericXAxisComponent } from "./igx-numeric-x-axis-component";
import { IgxCategoryYAxisComponent } from "./igx-category-y-axis-component";
import { IgxColumnFragmentComponent } from "./igx-column-fragment-component";
import { IgxFragmentBaseComponent } from "./igx-fragment-base-component";
import { IgxHorizontalAnchoredCategorySeriesComponent } from "./igx-horizontal-anchored-category-series-component";
import { IgxAnchoredCategorySeriesComponent } from "./igx-anchored-category-series-component";
import { IgxCategorySeriesComponent } from "./igx-category-series-component";
import { IgxMarkerSeriesComponent } from "./igx-marker-series-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { BarFragment } from "./BarFragment";
import { toPoint, fromRect } from "igniteui-angular-core";
import * as i0 from "@angular/core";
/**
 * Represents one part of a StackedBarSeries.
*/
export let IgxBarFragmentComponent = /*@__PURE__*/ (() => {
    class IgxBarFragmentComponent extends IgxColumnFragmentComponent {
        constructor() {
            super();
        }
        createImplementation() {
            return new BarFragment();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        /**
         * Gets whether the current series shows a bar shape.
        */
        get isBar() {
            return this.i.di;
        }
        /**
         * Overridden by derived series classes to indicate when marker-less display is preferred or not.
        */
        get isMarkerlessDisplayPreferred() {
            return this.i.d5;
        }
        /**
         * Gets whether the current series shows a column shape.
        */
        get isColumn() {
            return this.i.dk;
        }
        /**
         * The X-Axis for this BarFragment.
        */
        get barFragmentXAxis() {
            const r = this.i.barFragmentXAxis;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                let e = IgxNumericXAxisComponent._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        }
        /**
         * The Y-Axis for this BarFragment.
        */
        get barFragmentYAxis() {
            const r = this.i.barFragmentYAxis;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                let e = IgxCategoryYAxisComponent._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        }
        get isVertical() {
            return this.i.isVertical;
        }
        _styling(container, component, parent) {
            super._styling(container, component, parent);
            this._inStyling = true;
            if (this.barFragmentXAxis && this.barFragmentXAxis._styling) {
                this.barFragmentXAxis._styling(container, component, this);
            }
            if (this.barFragmentYAxis && this.barFragmentYAxis._styling) {
                this.barFragmentYAxis._styling(container, component, this);
            }
            this._inStyling = false;
        }
        /**
         * Gets the precise item index, if possible, based on the closeness to the previous or next whole integer. If the series cannot provide this information, GetExactItemIndex will return the same integer value as GetItemIndex.
        
        * @param world  * The world position for which to return the index.
        */
        getExactItemIndex(world) {
            let iv = this.i.f9(toPoint(world));
            return (iv);
        }
        /**
         * If possible, will return the best available value bounding box within the series that has the best value match for the world position provided.
        
        * @param world  * The world coordinate for which to get a value bounding box for
        */
        getSeriesValueBoundingBox(world) {
            let iv = this.i.p3(toPoint(world));
            return fromRect(iv);
        }
        /**
         * Gets the item that is the best match for the specified world coordinates.
        
        * @param world  * The world coordinates to use.
        */
        getItem(world) {
            let iv = this.i.hy(toPoint(world));
            return (iv);
        }
    }
    IgxBarFragmentComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: IgxBarFragmentComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    IgxBarFragmentComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.17", type: IgxBarFragmentComponent, selector: "igx-bar-fragment", providers: [{ provide: IgxColumnFragmentComponent, useExisting: forwardRef(() => IgxBarFragmentComponent) }, { provide: IgxFragmentBaseComponent, useExisting: forwardRef(() => IgxBarFragmentComponent) }, { provide: IgxHorizontalAnchoredCategorySeriesComponent, useExisting: forwardRef(() => IgxBarFragmentComponent) }, { provide: IgxAnchoredCategorySeriesComponent, useExisting: forwardRef(() => IgxBarFragmentComponent) }, { provide: IgxCategorySeriesComponent, useExisting: forwardRef(() => IgxBarFragmentComponent) }, { provide: IgxMarkerSeriesComponent, useExisting: forwardRef(() => IgxBarFragmentComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxBarFragmentComponent) }], usesInheritance: true, ngImport: i0, template: ``, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
    return IgxBarFragmentComponent;
})();
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: IgxBarFragmentComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'igx-bar-fragment',
                    template: ``,
                    providers: [{ provide: IgxColumnFragmentComponent, useExisting: forwardRef(() => IgxBarFragmentComponent) }, { provide: IgxFragmentBaseComponent, useExisting: forwardRef(() => IgxBarFragmentComponent) }, { provide: IgxHorizontalAnchoredCategorySeriesComponent, useExisting: forwardRef(() => IgxBarFragmentComponent) }, { provide: IgxAnchoredCategorySeriesComponent, useExisting: forwardRef(() => IgxBarFragmentComponent) }, { provide: IgxCategorySeriesComponent, useExisting: forwardRef(() => IgxBarFragmentComponent) }, { provide: IgxMarkerSeriesComponent, useExisting: forwardRef(() => IgxBarFragmentComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxBarFragmentComponent) }],
                    changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], ctorParameters: function () { return []; } });

==> igniteui-angular-charts-17.2.0-beta.0.tgz: package/esm2015/lib/igx-bar-fragment-component.js <==
import { Component, forwardRef, ChangeDetectionStrategy } from '@angular/core';
import { IgxNumericXAxisComponent } from "./igx-numeric-x-axis-component";
import { IgxCategoryYAxisComponent } from "./igx-category-y-axis-component";
import { IgxColumnFragmentComponent } from "./igx-column-fragment-component";
import { IgxFragmentBaseComponent } from "./igx-fragment-base-component";
import { IgxHorizontalAnchoredCategorySeriesComponent } from "./igx-horizontal-anchored-category-series-component";
import { IgxAnchoredCategorySeriesComponent } from "./igx-anchored-category-series-component";
import { IgxCategorySeriesComponent } from "./igx-category-series-component";
import { IgxMarkerSeriesComponent } from "./igx-marker-series-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { BarFragment } from "./BarFragment";
import { toPoint, fromRect } from "igniteui-angular-core";
import * as i0 from "@angular/core";
/**
 * Represents one part of a StackedBarSeries.
*/
export let IgxBarFragmentComponent = /*@__PURE__*/ (() => {
    class IgxBarFragmentComponent extends IgxColumnFragmentComponent {
        constructor() {
            super();
        }
        createImplementation() {
            return new BarFragment();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        /**
         * Gets whether the current series shows a bar shape.
        */
        get isBar() {
            return this.i.eb;
        }
        /**
         * Overridden by derived series classes to indicate when marker-less display is preferred or not.
        */
        get isMarkerlessDisplayPreferred() {
            return this.i.ey;
        }
        /**
         * Gets whether the current series shows a column shape.
        */
        get isColumn() {
            return this.i.ed;
        }
        /**
         * The X-Axis for this BarFragment.
        */
        get barFragmentXAxis() {
            const r = this.i.barFragmentXAxis;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                let e = IgxNumericXAxisComponent._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        }
        /**
         * The Y-Axis for this BarFragment.
        */
        get barFragmentYAxis() {
            const r = this.i.barFragmentYAxis;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                let e = IgxCategoryYAxisComponent._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        }
        get isVertical() {
            return this.i.isVertical;
        }
        _styling(container, component, parent) {
            super._styling(container, component, parent);
            this._inStyling = true;
            if (this.barFragmentXAxis && this.barFragmentXAxis._styling) {
                this.barFragmentXAxis._styling(container, component, this);
            }
            if (this.barFragmentYAxis && this.barFragmentYAxis._styling) {
                this.barFragmentYAxis._styling(container, component, this);
            }
            this._inStyling = false;
        }
        /**
         * Gets the precise item index, if possible, based on the closeness to the previous or next whole integer. If the series cannot provide this information, GetExactItemIndex will return the same integer value as GetItemIndex.
        
        * @param world  * The world position for which to return the index.
        */
        getExactItemIndex(world) {
            let iv = this.i.hv(toPoint(world));
            return (iv);
        }
        /**
         * If possible, will return the best available value bounding box within the series that has the best value match for the world position provided.
        
        * @param world  * The world coordinate for which to get a value bounding box for
        */
        getSeriesValueBoundingBox(world) {
            let iv = this.i.ts(toPoint(world));
            return fromRect(iv);
        }
        /**
         * Gets the item that is the best match for the specified world coordinates.
        
        * @param world  * The world coordinates to use.
        */
        getItem(world) {
            let iv = this.i.jr(toPoint(world));
            return (iv);
        }
    }
    IgxBarFragmentComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: IgxBarFragmentComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    IgxBarFragmentComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.17", type: IgxBarFragmentComponent, selector: "igx-bar-fragment", providers: [{ provide: IgxColumnFragmentComponent, useExisting: forwardRef(() => IgxBarFragmentComponent) }, { provide: IgxFragmentBaseComponent, useExisting: forwardRef(() => IgxBarFragmentComponent) }, { provide: IgxHorizontalAnchoredCategorySeriesComponent, useExisting: forwardRef(() => IgxBarFragmentComponent) }, { provide: IgxAnchoredCategorySeriesComponent, useExisting: forwardRef(() => IgxBarFragmentComponent) }, { provide: IgxCategorySeriesComponent, useExisting: forwardRef(() => IgxBarFragmentComponent) }, { provide: IgxMarkerSeriesComponent, useExisting: forwardRef(() => IgxBarFragmentComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxBarFragmentComponent) }], usesInheritance: true, ngImport: i0, template: ``, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
    return IgxBarFragmentComponent;
})();
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: IgxBarFragmentComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'igx-bar-fragment',
                    template: ``,
                    providers: [{ provide: IgxColumnFragmentComponent, useExisting: forwardRef(() => IgxBarFragmentComponent) }, { provide: IgxFragmentBaseComponent, useExisting: forwardRef(() => IgxBarFragmentComponent) }, { provide: IgxHorizontalAnchoredCategorySeriesComponent, useExisting: forwardRef(() => IgxBarFragmentComponent) }, { provide: IgxAnchoredCategorySeriesComponent, useExisting: forwardRef(() => IgxBarFragmentComponent) }, { provide: IgxCategorySeriesComponent, useExisting: forwardRef(() => IgxBarFragmentComponent) }, { provide: IgxMarkerSeriesComponent, useExisting: forwardRef(() => IgxBarFragmentComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxBarFragmentComponent) }],
                    changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], ctorParameters: function () { return []; } });
